libsolv/0001-Always-do-nevr-check-for-src-rpms-even-if-there-are-.patch

31 lines
903 B
Diff
Raw Normal View History

From 69439fe4eea683200aa6449ac6632f4283997e49 Mon Sep 17 00:00:00 2001
From: Michael Schroeder <mls@suse.de>
Date: Mon, 1 Jul 2019 14:52:24 +0200
Subject: [PATCH] Always do nevr check for src rpms, even if there are provides
Newer rpm versions add a "rpmlib(DynamicBuildRequires)" provides
to source rpms in some cases. Sigh.
---
src/pool.c | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
diff --git a/src/pool.c b/src/pool.c
index a5544531..5651f85a 100644
--- a/src/pool.c
+++ b/src/pool.c
@@ -1355,9 +1355,9 @@ pool_addrelproviders(Pool *pool, Id d)
continue;
}
}
- if (!s->provides)
+ if (!s->provides || s->arch == ARCH_SRC || s->arch == ARCH_NOSRC)
{
/* no provides - check nevr */
if (pool_match_nevr_rel(pool, s, MAKERELDEP(d)))
queue_push(&plist, p);
continue;
@@ -1355,9 +1355,9 @@ pool_addrelproviders(Pool *pool, Id d)
{
- /* no provides - check nevr */
+ /* no provides or src rpm - check nevr */
if (pool_match_nevr_rel(pool, s, MAKERELDEP(d)))
queue_push(&plist, p);
--
2.22.0